@@ -3,7 +3,7 @@ use 5.008001;
 use strict;
 use warnings;
 
-our $VERSION = '1.043';
+our $VERSION = '1.044';
 
 =head1 NAME
 
@@ -52,7 +52,7 @@ use constant OPTIONS => {
     'f|filter:s@'    => 'Input filters for scripts',
     'g|gui'          => 'No console window',
     'I|lib:s@'       => 'Include directories (for perl)',
-    'l|link:s@'      => 'Include additional shared libraries',
+    'l|link:s@'      => 'Additional shared libraries to pack',
     'L|log:s'        => 'Where to log packaging process information',
     'F|modfilter:s@' => 'Input filter for perl modules',
     'M|module|add:s@'=> 'Include modules',
@@ -451,7 +451,6 @@ sub run_pack {
 sub _compile_par {
     my ($self) = @_;
 
-    my @SharedLibs;
     local (@INC) = @INC;
 
     my $lose = $self->{pack_attrib}{lose};
@@ -1550,7 +1549,7 @@ sub _find_shlib {
         return $abs_file;
     }
 
-    $self->_die("Shared library (option -l) doesn't exist: $file")
+    $self->_die("Shared library (option --link) doesn't exist: $file")
         if $file =~ /[\/\\]/;
 
     my @libpath;
@@ -1574,7 +1573,7 @@ sub _find_shlib {
         return $lib;
     }
 
-    $self->_die("Can't find shared library (option -l): $file")
+    $self->_die("Can't find shared library (option --link): $file")
         if $^O eq 'MSWin32' || $file =~ /^lib/;
 
     # be extra magical and prepend "lib" to the filename
@@ -1583,7 +1582,7 @@ sub _find_shlib {
         return $lib;
     }
 
-    $self->_die("Can't find shared library (option -l): $file (also tried lib$file)");
+    $self->_die("Can't find shared library (option --link): $file (also tried lib$file)");
 }
 
 sub _find_shlib_in_path
